exceptiontools.ExtraSpannerError
================================

.. inheritance-diagram:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
